Enum bobascript_parser::ast::Expr [−][src]
pub enum Expr {
Error,
Log(Box<Expr>),
Block(Vec<Box<Stmt>>, Option<Box<Expr>>),
If(Box<Expr>, Box<Expr>, Option<Box<Expr>>),
While(Box<Expr>, Vec<Box<Stmt>>),
Assign(Box<Expr>, AssignOp, Box<Expr>),
Binary(Box<Expr>, BinaryOp, Box<Expr>),
Unary(UnaryOp, Box<Expr>),
Property(Box<Expr>, String),
Index(Box<Expr>, Box<Expr>),
Call(Box<Expr>, Vec<Box<Expr>>),
Constant(Constant),
}Variants
Outputs the value of the contained Expr as a log.
The first Expr is the condition, the second the “true” block, and the third the “false” block.
Else-if statements are collapsed as if a standard if statement was put inside of the else block.
Constant(Constant)Trait Implementations